# SwaggerClient-php
UltraCart REST API Version 2

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Build package: io.swagger.codegen.languages.PhpClientCodegen
For more information, please visit [http://www.ultracart.com](http://www.ultracart.com)

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/UltraCart/rest_api_v2_sdk_php.git"
    }
  ],
  "require": {
    "UltraCart/rest_api_v2_sdk_php": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/vendor/whatever_you_named_your_ultracart_sdk_directory/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php /* docs.ultracart.com sample */ ?>

<?php
// for testing and development only
set_time_limit(3000);
ini_set('max_execution_time', 3000);
ini_set('display_errors', 1);
error_reporting(E_ALL);
?>

<?php
// initialization code
require_once './vendor/autoload.php';
$simple_key = '4256aaf6dfedfa01582fe9a961ab0100216d737b874a4801582fe9a961ab0100';
ultracart\v2\Configuration::getDefaultConfiguration()->setApiKey('x-ultracart-simple-key', $simple_key);

$client = new GuzzleHttp\Client(['verify' => true, 'debug' => false]);
$config = ultracart\v2\Configuration::getDefaultConfiguration();
$headerSelector = new \ultracart\v2\HeaderSelector(/* leave null for version tied to this sdk version */);

$auto_order_api = new ultracart\v2\Api\AutoorderApi($client, $config, $headerSelector);
?>

<html>
<body>
<?php

try {
    $auto_order_oid = 2078718;  // this is found either by looping through auto orders, or from the back end.
    $auto_order_response = $auto_order_api->getAutoOrder($auto_order_oid, "items");
    $auto_order = $auto_order_response->getAutoOrder();
    $auto_order->getItems()[0]->setArbitraryQuantity(4);
    $auto_order_response = $auto_order_api->updateAutoOrder($auto_order, $auto_order_oid);

} catch (\ultracart\v2\ApiException $e) {
    error_log($e->getResponseBody());
}

?>
<pre>
<?php echo print_r($auto_order); ?>
<?php echo print_r($auto_order_response); ?>
</pre>
<?php echo 'Finished.'; ?>
</body>
</html>
```

## Documentation for API Endpoints

All URIs are relative to *https://secure.ultracart.com/rest/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AffiliateApi* | [**getClicksByQuery**](docs/Api/AffiliateApi.md#getclicksbyquery) | **POST** /affiliate/clicks/query | Retrieve clicks
*AffiliateApi* | [**getLedgersByQuery**](docs/Api/AffiliateApi.md#getledgersbyquery) | **POST** /affiliate/ledgers/query | Retrieve ledger entries
*AutoOrderApi* | [**getAutoOrder**](docs/Api/AutoOrderApi.md#getautoorder) | **GET** /auto_order/auto_orders/{auto_order_oid} | Retrieve an auto order
*AutoOrderApi* | [**getAutoOrderByCode**](docs/Api/AutoOrderApi.md#getautoorderbycode) | **GET** /auto_order/auto_orders/code/{auto_order_code} | Retrieve an auto order
*AutoOrderApi* | [**getAutoOrderByReferenceOrderId**](docs/Api/AutoOrderApi.md#getautoorderbyreferenceorderid) | **GET** /auto_order/auto_orders/reference_order_id/{reference_order_id} | Retrieve an auto order
*AutoOrderApi* | [**getAutoOrders**](docs/Api/AutoOrderApi.md#getautoorders) | **GET** /auto_order/auto_orders | Retrieve auto orders
*AutoOrderApi* | [**getAutoOrdersByQuery**](docs/Api/AutoOrderApi.md#getautoordersbyquery) | **POST** /auto_order/auto_orders/query | Retrieve auto orders
*AutoOrderApi* | [**updateAutoOrder**](docs/Api/AutoOrderApi.md#updateautoorder) | **PUT** /auto_order/auto_orders/{auto_order_oid} | Update an auto order
*ChargebackApi* | [**deleteChargeback**](docs/Api/ChargebackApi.md#deletechargeback) | **DELETE** /chargeback/chargebacks/{chargeback_dispute_oid} | Delete a chargeback
*ChargebackApi* | [**getChargebackDispute**](docs/Api/ChargebackApi.md#getchargebackdispute) | **GET** /chargeback/chargebacks/{chargeback_dispute_oid} | Retrieve a chargeback
*ChargebackApi* | [**getChargebackDisputes**](docs/Api/ChargebackApi.md#getchargebackdisputes) | **GET** /chargeback/chargebacks | Retrieve chargebacks
*ChargebackApi* | [**insertChargeback**](docs/Api/ChargebackApi.md#insertchargeback) | **POST** /chargeback/chargebacks | Insert a chargeback
*ChargebackApi* | [**updateChargeback**](docs/Api/ChargebackApi.md#updatechargeback) | **PUT** /chargeback/chargebacks/{chargeback_dispute_oid} | Update a chargeback
*CheckoutApi* | [**cityState**](docs/Api/CheckoutApi.md#citystate) | **POST** /checkout/city_state | City/State for Zip
*CheckoutApi* | [**finalizeOrder**](docs/Api/CheckoutApi.md#finalizeorder) | **POST** /checkout/cart/finalizeOrder | Finalize Order
*CheckoutApi* | [**getAffirmCheckout**](docs/Api/CheckoutApi.md#getaffirmcheckout) | **GET** /checkout/cart/{cart_id}/affirmCheckout | Get affirm checkout (by cart id)
*CheckoutApi* | [**getAllowedCountries**](docs/Api/CheckoutApi.md#getallowedcountries) | **POST** /checkout/allowedCountries | Allowed countries
*CheckoutApi* | [**getCart**](docs/Api/CheckoutApi.md#getcart) | **GET** /checkout/cart | Get cart
*CheckoutApi* | [**getCartByCartId**](docs/Api/CheckoutApi.md#getcartbycartid) | **GET** /checkout/cart/{cart_id} | Get cart (by cart id)
*CheckoutApi* | [**getCartByReturnCode**](docs/Api/CheckoutApi.md#getcartbyreturncode) | **GET** /checkout/return/{return_code} | Get cart (by return code)
*CheckoutApi* | [**getStateProvincesForCountry**](docs/Api/CheckoutApi.md#getstateprovincesforcountry) | **POST** /checkout/stateProvincesForCountry/{country_code} | Get state/province list for a country code
*CheckoutApi* | [**handoffCart**](docs/Api/CheckoutApi.md#handoffcart) | **POST** /checkout/cart/handoff | Handoff cart
*CheckoutApi* | [**login**](docs/Api/CheckoutApi.md#login) | **POST** /checkout/cart/profile/login | Profile login
*CheckoutApi* | [**logout**](docs/Api/CheckoutApi.md#logout) | **POST** /checkout/cart/profile/logout | Profile logout
*CheckoutApi* | [**register**](docs/Api/CheckoutApi.md#register) | **POST** /checkout/cart/profile/register | Profile registration
*CheckoutApi* | [**relatedItemsForCart**](docs/Api/CheckoutApi.md#relateditemsforcart) | **POST** /checkout/related_items | Related items
*CheckoutApi* | [**relatedItemsForItem**](docs/Api/CheckoutApi.md#relateditemsforitem) | **POST** /checkout/relatedItems/{item_id} | Related items (specific item)
*CheckoutApi* | [**setupBrowserKey**](docs/Api/CheckoutApi.md#setupbrowserkey) | **PUT** /checkout/browser_key | Setup Browser Application
*CheckoutApi* | [**updateCart**](docs/Api/CheckoutApi.md#updatecart) | **PUT** /checkout/cart | Update cart
*CheckoutApi* | [**validateCart**](docs/Api/CheckoutApi.md#validatecart) | **POST** /checkout/cart/validate | Validate
*CouponApi* | [**deleteCoupon**](docs/Api/CouponApi.md#deletecoupon) | **DELETE** /coupon/coupons/{coupon_oid} | Delete a coupon
*CouponApi* | [**generateCouponCodes**](docs/Api/CouponApi.md#generatecouponcodes) | **POST** /coupon/coupons/{coupon_oid}/generate_codes | Generates one time codes for a coupon
*CouponApi* | [**generateOneTimeCodesByMerchantCode**](docs/Api/CouponApi.md#generateonetimecodesbymerchantcode) | **POST** /coupon/coupons/merchant_code/{merchant_code}/generate_codes | Generates one time codes by merchant code
*CouponApi* | [**getCoupon**](docs/Api/CouponApi.md#getcoupon) | **GET** /coupon/coupons/{coupon_oid} | Retrieve a coupon
*CouponApi* | [**getCouponByMerchantCode**](docs/Api/CouponApi.md#getcouponbymerchantcode) | **GET** /coupon/coupons/merchant_code/{merchant_code} | Retrieve a coupon by merchant code
*CouponApi* | [**getCoupons**](docs/Api/CouponApi.md#getcoupons) | **GET** /coupon/coupons | Retrieve coupons
*CouponApi* | [**getCouponsByQuery**](docs/Api/CouponApi.md#getcouponsbyquery) | **GET** /coupon/coupons/query | Retrieve coupons by query
*CouponApi* | [**getEditorValues**](docs/Api/CouponApi.md#geteditorvalues) | **GET** /coupon/editor_values | Retrieve values needed for a coupon editor
*CouponApi* | [**insertCoupon**](docs/Api/CouponApi.md#insertcoupon) | **POST** /coupon/coupons | Insert a coupon
*CouponApi* | [**updateCoupon**](docs/Api/CouponApi.md#updatecoupon) | **PUT** /coupon/coupons/{coupon_oid} | Update a coupon
*CustomerApi* | [**deleteCustomer**](docs/Api/CustomerApi.md#deletecustomer) | **DELETE** /customer/customers/{customer_profile_oid} | Delete a customer
*CustomerApi* | [**getCustomer**](docs/Api/CustomerApi.md#getcustomer) | **GET** /customer/customers/{customer_profile_oid} | Retrieve a customer
*CustomerApi* | [**getCustomers**](docs/Api/CustomerApi.md#getcustomers) | **GET** /customer/customers | Retrieve customers
*CustomerApi* | [**getCustomersByQuery**](docs/Api/CustomerApi.md#getcustomersbyquery) | **GET** /customer/customers/query | Retrieve customers by query
*CustomerApi* | [**getCustomersForDataTables**](docs/Api/CustomerApi.md#getcustomersfordatatables) | **POST** /customer/customers/dataTables | Retrieve customers for DataTables plugin
*CustomerApi* | [**getEditorValues**](docs/Api/CustomerApi.md#geteditorvalues) | **GET** /customer/editor_values | Retrieve values needed for a customer profile editor
*CustomerApi* | [**insertCustomer**](docs/Api/CustomerApi.md#insertcustomer) | **POST** /customer/customers | Insert a customer
*CustomerApi* | [**updateCustomer**](docs/Api/CustomerApi.md#updatecustomer) | **PUT** /customer/customers/{customer_profile_oid} | Update a customer
*FulfillmentApi* | [**acknowledgeOrders**](docs/Api/FulfillmentApi.md#acknowledgeorders) | **PUT** /fulfillment/distribution_centers/{distribution_center_code}/acknowledgements | Acknowledge receipt of orders.
*FulfillmentApi* | [**getDistributionCenterOrders**](docs/Api/FulfillmentApi.md#getdistributioncenterorders) | **GET** /fulfillment/distribution_centers/{distribution_center_code}/orders | Retrieve orders queued up for this distribution center.
*FulfillmentApi* | [**getDistributionCenters**](docs/Api/FulfillmentApi.md#getdistributioncenters) | **GET** /fulfillment/distribution_centers | Retrieve distribution centers
*FulfillmentApi* | [**shipOrders**](docs/Api/FulfillmentApi.md#shiporders) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/shipments | Mark orders as shipped
*FulfillmentApi* | [**updateInventory**](docs/Api/FulfillmentApi.md#updateinventory) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/inventory | Update inventory
*ItemApi* | [**deleteItem**](docs/Api/ItemApi.md#deleteitem) | **DELETE** /item/items/{merchant_item_oid} | Delete an item
*ItemApi* | [**getItem**](docs/Api/ItemApi.md#getitem) | **GET** /item/items/{merchant_item_oid} | Retrieve an item
*ItemApi* | [**getItemByMerchantItemId**](docs/Api/ItemApi.md#getitembymerchantitemid) | **GET** /item/items/merchant_item_id/{merchant_item_id} | Retrieve an item by item id
*ItemApi* | [**getItems**](docs/Api/ItemApi.md#getitems) | **GET** /item/items | Retrieve items
*ItemApi* | [**getPricingTiers**](docs/Api/ItemApi.md#getpricingtiers) | **GET** /item/pricing_tiers | Retrieve pricing tiers
*ItemApi* | [**insertItem**](docs/Api/ItemApi.md#insertitem) | **POST** /item/items | Create an item
*ItemApi* | [**updateItem**](docs/Api/ItemApi.md#updateitem) | **PUT** /item/items/{merchant_item_oid} | Update an item
*ItemApi* | [**updateItems**](docs/Api/ItemApi.md#updateitems) | **PUT** /item/items/batch | Update multiple items
*ItemApi* | [**uploadTemporaryMultimedia**](docs/Api/ItemApi.md#uploadtemporarymultimedia) | **POST** /item/temp_multimedia | Upload an image to the temporary multimedia.
*OauthApi* | [**oauthAccessToken**](docs/Api/OauthApi.md#oauthaccesstoken) | **POST** /oauth/token | Exchange authorization code for access token.
*OauthApi* | [**oauthRevoke**](docs/Api/OauthApi.md#oauthrevoke) | **POST** /oauth/revoke | Revoke this OAuth application.
*OrderApi* | [**cancelOrder**](docs/Api/OrderApi.md#cancelorder) | **POST** /order/orders/{order_id}/cancel | Cancel an order
*OrderApi* | [**deleteOrder**](docs/Api/OrderApi.md#deleteorder) | **DELETE** /order/orders/{order_id} | Delete an order
*OrderApi* | [**format**](docs/Api/OrderApi.md#format) | **POST** /order/orders/{order_id}/format | Format order
*OrderApi* | [**getAccountsReceivableRetryConfig**](docs/Api/OrderApi.md#getaccountsreceivableretryconfig) | **GET** /order/accountsReceivableRetryConfig | Retrieve A/R Retry Configuration
*OrderApi* | [**getAccountsReceivableRetryStats**](docs/Api/OrderApi.md#getaccountsreceivableretrystats) | **GET** /order/accountsReceivableRetryConfig/stats | Retrieve A/R Retry Statistics
*OrderApi* | [**getOrder**](docs/Api/OrderApi.md#getorder) | **GET** /order/orders/{order_id} | Retrieve an order
*OrderApi* | [**getOrders**](docs/Api/OrderApi.md#getorders) | **GET** /order/orders | Retrieve orders
*OrderApi* | [**getOrdersByQuery**](docs/Api/OrderApi.md#getordersbyquery) | **POST** /order/orders/query | Retrieve orders
*OrderApi* | [**insertOrder**](docs/Api/OrderApi.md#insertorder) | **POST** /order/orders | Insert an order
*OrderApi* | [**refundOrder**](docs/Api/OrderApi.md#refundorder) | **PUT** /order/orders/{order_id}/refund | Refund an order
*OrderApi* | [**replacement**](docs/Api/OrderApi.md#replacement) | **POST** /order/orders/{order_id}/replacement | Replacement order
*OrderApi* | [**resendReceipt**](docs/Api/OrderApi.md#resendreceipt) | **POST** /order/orders/{order_id}/resend_receipt | Resend receipt
*OrderApi* | [**resendShipmentConfirmation**](docs/Api/OrderApi.md#resendshipmentconfirmation) | **POST** /order/orders/{order_id}/resend_shipment_confirmation | Resend shipment confirmation
*OrderApi* | [**updateAccountsReceivableRetryConfig**](docs/Api/OrderApi.md#updateaccountsreceivableretryconfig) | **POST** /order/accountsReceivableRetryConfig | Update A/R Retry Configuration
*OrderApi* | [**updateOrder**](docs/Api/OrderApi.md#updateorder) | **PUT** /order/orders/{order_id} | Update an order
*StorefrontApi* | [**archiveEmailList**](docs/Api/StorefrontApi.md#archiveemaillist) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/archive | Archive email list
*StorefrontApi* | [**archiveEmailSegment**](docs/Api/StorefrontApi.md#archiveemailsegment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/archive | Archive email segment
*StorefrontApi* | [**cloneEmailCampaign**](docs/Api/StorefrontApi.md#cloneemailcampaign) | **POST** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/clone | Clone email campaign
*StorefrontApi* | [**cloneEmailFlow**](docs/Api/StorefrontApi.md#cloneemailflow) | **POST** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/clone | Clone email flow
*StorefrontApi* | [**deleteEmailEmail**](docs/Api/StorefrontApi.md#deleteemailemail) | **DELETE** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Delete email email
*StorefrontApi* | [**getEmailBaseTemplates**](docs/Api/StorefrontApi.md#getemailbasetemplates) | **GET** /storefront/{storefront_oid}/email/baseTemplates | Get email communication base templates
*StorefrontApi* | [**getEmailCampaign**](docs/Api/StorefrontApi.md#getemailcampaign) | **GET** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Get email campaign
*StorefrontApi* | [**getEmailCampaigns**](docs/Api/StorefrontApi.md#getemailcampaigns) | **GET** /storefront/{storefront_oid}/email/campaigns | Get email campaigns
*StorefrontApi* | [**getEmailCampaignsWithStats**](docs/Api/StorefrontApi.md#getemailcampaignswithstats) | **GET** /storefront/{storefront_oid}/email/campaignsWithStats/{stat_days} | Get email campaigns with stats
*StorefrontApi* | [**getEmailCommseq**](docs/Api/StorefrontApi.md#getemailcommseq) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Get email commseq
*StorefrontApi* | [**getEmailCommseqEmailStats**](docs/Api/StorefrontApi.md#getemailcommseqemailstats) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/emailStats/{commseq_email_uuid} | Get email communication sequence emails stats
*StorefrontApi* | [**getEmailCommseqStats**](docs/Api/StorefrontApi.md#getemailcommseqstats) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stats | Get email communication sequence stats
*StorefrontApi* | [**getEmailCommseqs**](docs/Api/StorefrontApi.md#getemailcommseqs) | **GET** /storefront/{storefront_oid}/email/commseqs | Get email commseqs
*StorefrontApi* | [**getEmailEmail**](docs/Api/StorefrontApi.md#getemailemail) | **GET** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Get email email
*StorefrontApi* | [**getEmailEmails**](docs/Api/StorefrontApi.md#getemailemails) | **GET** /storefront/{storefront_oid}/email/emails | Get email emails
*StorefrontApi* | [**getEmailFlow**](docs/Api/StorefrontApi.md#getemailflow) | **GET** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Get email flow
*StorefrontApi* | [**getEmailFlows**](docs/Api/StorefrontApi.md#getemailflows) | **GET** /storefront/{storefront_oid}/email/flows | Get email flows
*StorefrontApi* | [**getEmailList**](docs/Api/StorefrontApi.md#getemaillist) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Get email list
*StorefrontApi* | [**getEmailLists**](docs/Api/StorefrontApi.md#getemaillists) | **GET** /storefront/{storefront_oid}/email/lists | Get email lists
*StorefrontApi* | [**getEmailSegment**](docs/Api/StorefrontApi.md#getemailsegment) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Get email segment
*StorefrontApi* | [**getEmailSegments**](docs/Api/StorefrontApi.md#getemailsegments) | **GET** /storefront/{storefront_oid}/email/segments | Get email segments
*StorefrontApi* | [**getEmailStats**](docs/Api/StorefrontApi.md#getemailstats) | **GET** /storefront/{storefront_oid}/email/dashboard_stats | Get email stats
*StorefrontApi* | [**getEmailTemplate**](docs/Api/StorefrontApi.md#getemailtemplate) | **GET** /storefront/{storefront_oid}/email/templates/{email_template_oid} | Get email template
*StorefrontApi* | [**getEmailTemplates**](docs/Api/StorefrontApi.md#getemailtemplates) | **GET** /storefront/{storefront_oid}/email/templates | Get email templates
*StorefrontApi* | [**insertEmailCampaign**](docs/Api/StorefrontApi.md#insertemailcampaign) | **POST** /storefront/{storefront_oid}/email/campaigns | Insert email campaign
*StorefrontApi* | [**insertEmailCommseq**](docs/Api/StorefrontApi.md#insertemailcommseq) | **POST** /storefront/{storefront_oid}/email/commseqs | Insert email commseq
*StorefrontApi* | [**insertEmailEmail**](docs/Api/StorefrontApi.md#insertemailemail) | **POST** /storefront/{storefront_oid}/email/emails | Insert email email
*StorefrontApi* | [**insertEmailFlow**](docs/Api/StorefrontApi.md#insertemailflow) | **POST** /storefront/{storefront_oid}/email/flows | Insert email flow
*StorefrontApi* | [**insertEmailList**](docs/Api/StorefrontApi.md#insertemaillist) | **POST** /storefront/{storefront_oid}/email/lists | Insert email list
*StorefrontApi* | [**insertEmailSegment**](docs/Api/StorefrontApi.md#insertemailsegment) | **POST** /storefront/{storefront_oid}/email/segments | Insert email segment
*StorefrontApi* | [**startEmailCampaign**](docs/Api/StorefrontApi.md#startemailcampaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/start | Start email campaign
*StorefrontApi* | [**subscribeToEmailList**](docs/Api/StorefrontApi.md#subscribetoemaillist) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/subscribe | Subscribe customers to email list
*StorefrontApi* | [**updateEmailCampaign**](docs/Api/StorefrontApi.md#updateemailcampaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Update email campaign
*StorefrontApi* | [**updateEmailCommseq**](docs/Api/StorefrontApi.md#updateemailcommseq) | **PUT** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Update email commseq
*StorefrontApi* | [**updateEmailEmail**](docs/Api/StorefrontApi.md#updateemailemail) | **PUT** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Update email email
*StorefrontApi* | [**updateEmailFlow**](docs/Api/StorefrontApi.md#updateemailflow) | **PUT** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Update email flow
*StorefrontApi* | [**updateEmailList**](docs/Api/StorefrontApi.md#updateemaillist) | **PUT** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Update email list
*StorefrontApi* | [**updateEmailSegment**](docs/Api/StorefrontApi.md#updateemailsegment) | **PUT** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Update email segment
*TaxApi* | [**deleteTaxProviderSelfCity**](docs/Api/TaxApi.md#deletetaxproviderselfcity) | **DELETE** /tax/providers/self/city/{city} | Deletes a Self tax provider city
*TaxApi* | [**deleteTaxProviderSelfCountry**](docs/Api/TaxApi.md#deletetaxproviderselfcountry) | **DELETE** /tax/providers/self/country/{countryCode} | Deletes a Self tax provider country
*TaxApi* | [**deleteTaxProviderSelfCounty**](docs/Api/TaxApi.md#deletetaxproviderselfcounty) | **DELETE** /tax/providers/self/county/{county} | Deletes a Self tax provider county
*TaxApi* | [**deleteTaxProviderSelfPostalCode**](docs/Api/TaxApi.md#deletetaxproviderselfpostalcode) | **DELETE** /tax/providers/self/postalCode/{postal_code} | Deletes a Self tax provider postalCode
*TaxApi* | [**deleteTaxProviderSelfState**](docs/Api/TaxApi.md#deletetaxproviderselfstate) | **DELETE** /tax/providers/self/state/{stateCode} | Deletes a Self tax provider state
*TaxApi* | [**getTaxProviderAvalara**](docs/Api/TaxApi.md#gettaxprovideravalara) | **GET** /tax/providers/avalara | Retrieve the Avalara tax provider
*TaxApi* | [**getTaxProviderAvalaraCompanies**](docs/Api/TaxApi.md#gettaxprovideravalaracompanies) | **POST** /tax/providers/avalara/companies | Returns Avalara Tax companies configured by the merchant
*TaxApi* | [**getTaxProviderAvalaraTest**](docs/Api/TaxApi.md#gettaxprovideravalaratest) | **GET** /tax/providers/avalara/test | Attempts to connect to Avalara and returns back the response
*TaxApi* | [**getTaxProviderSelf**](docs/Api/TaxApi.md#gettaxproviderself) | **GET** /tax/providers/self | Retrieve the Self tax provider
*TaxApi* | [**getTaxProviderSelfCountries**](docs/Api/TaxApi.md#gettaxproviderselfcountries) | **GET** /tax/providers/self/countries | Retrieve the Self tax provider countries
*TaxApi* | [**getTaxProviderSelfRegionsByCountryCode**](docs/Api/TaxApi.md#gettaxproviderselfregionsbycountrycode) | **GET** /tax/providers/self/regions/{countryCode} | Retrieve the Self tax provider regions for a given country code
*TaxApi* | [**getTaxProviderTaxJar**](docs/Api/TaxApi.md#gettaxprovidertaxjar) | **GET** /tax/providers/taxjar | Retrieve the TaxJar tax provider
*TaxApi* | [**getTaxProviderTaxJarTest**](docs/Api/TaxApi.md#gettaxprovidertaxjartest) | **GET** /tax/providers/taxjar/test | Attempts to connect to TaxJar and returns back the response
*TaxApi* | [**getTaxProviderUltraCart**](docs/Api/TaxApi.md#gettaxproviderultracart) | **GET** /tax/providers/ultracart | Retrieve the UltraCart tax provider
*TaxApi* | [**getTaxProviders**](docs/Api/TaxApi.md#gettaxproviders) | **GET** /tax/providers | Retrieve tax methods
*TaxApi* | [**setActiveTaxProvider**](docs/Api/TaxApi.md#setactivetaxprovider) | **POST** /tax/providers/setActive/{providerName} | Toggle a tax provider to active
*TaxApi* | [**updateTaxProviderAvalara**](docs/Api/TaxApi.md#updatetaxprovideravalara) | **POST** /tax/providers/avalara | Update the Avalara tax provider
*TaxApi* | [**updateTaxProviderSelf**](docs/Api/TaxApi.md#updatetaxproviderself) | **POST** /tax/providers/self | Update the Self tax provider
*TaxApi* | [**updateTaxProviderSelfCity**](docs/Api/TaxApi.md#updatetaxproviderselfcity) | **POST** /tax/providers/self/city/{city} | Updates a Self tax provider city
*TaxApi* | [**updateTaxProviderSelfCountry**](docs/Api/TaxApi.md#updatetaxproviderselfcountry) | **POST** /tax/providers/self/country/{countryCode} | Updates a Self tax provider country
*TaxApi* | [**updateTaxProviderSelfCounty**](docs/Api/TaxApi.md#updatetaxproviderselfcounty) | **POST** /tax/providers/self/county/{county} | Updates a Self tax provider county
*TaxApi* | [**updateTaxProviderSelfPostalCode**](docs/Api/TaxApi.md#updatetaxproviderselfpostalcode) | **POST** /tax/providers/self/postalCode/{postal_code} | Updates a Self tax provider postalCode
*TaxApi* | [**updateTaxProviderSelfState**](docs/Api/TaxApi.md#updatetaxproviderselfstate) | **POST** /tax/providers/self/state/{stateCode} | Updates a Self tax provider state
*TaxApi* | [**updateTaxProviderTaxJar**](docs/Api/TaxApi.md#updatetaxprovidertaxjar) | **POST** /tax/providers/taxjar | Update the TaxJar tax provider
*TaxApi* | [**updateTaxProviderUltraCart**](docs/Api/TaxApi.md#updatetaxproviderultracart) | **POST** /tax/providers/ultracart | Update the UltraCart tax provider
*WebhookApi* | [**deleteWebhook**](docs/Api/WebhookApi.md#deletewebhook) | **DELETE** /webhook/webhooks/{webhookOid} | Delete a webhook
*WebhookApi* | [**getWebhookLog**](docs/Api/WebhookApi.md#getwebhooklog) | **GET** /webhook/webhooks/{webhookOid}/logs/{requestId} | Retrieve an individual log
*WebhookApi* | [**getWebhookLogSummaries**](docs/Api/WebhookApi.md#getwebhooklogsummaries) | **GET** /webhook/webhooks/{webhookOid}/logs | Retrieve the log summaries
*WebhookApi* | [**getWebhooks**](docs/Api/WebhookApi.md#getwebhooks) | **GET** /webhook/webhooks | Retrieve webhooks
*WebhookApi* | [**insertWebhook**](docs/Api/WebhookApi.md#insertwebhook) | **POST** /webhook/webhooks | Add a webhook
*WebhookApi* | [**resendEvent**](docs/Api/WebhookApi.md#resendevent) | **POST** /webhook/webhooks/{webhookOid}/reflow/{eventName} | Resend events to the webhook endpoint.
*WebhookApi* | [**updateWebhook**](docs/Api/WebhookApi.md#updatewebhook) | **PUT** /webhook/webhooks/{webhookOid} | Update a webhook


## Documentation For Models

 - [AccountsReceivableRetryConfig](docs/Model/AccountsReceivableRetryConfig.md)
 - [AccountsReceivableRetryConfigResponse](docs/Model/AccountsReceivableRetryConfigResponse.md)
 - [AccountsReceivableRetryDayActivity](docs/Model/AccountsReceivableRetryDayActivity.md)
 - [AccountsReceivableRetryStatAccount](docs/Model/AccountsReceivableRetryStatAccount.md)
 - [AccountsReceivableRetryStatMetrics](docs/Model/AccountsReceivableRetryStatMetrics.md)
 - [AccountsReceivableRetryStatRevenue](docs/Model/AccountsReceivableRetryStatRevenue.md)
 - [AccountsReceivableRetryStatsResponse](docs/Model/AccountsReceivableRetryStatsResponse.md)
 - [AffiliateClick](docs/Model/AffiliateClick.md)
 - [AffiliateClickQuery](docs/Model/AffiliateClickQuery.md)
 - [AffiliateClicksResponse](docs/Model/AffiliateClicksResponse.md)
 - [AffiliateLedger](docs/Model/AffiliateLedger.md)
 - [AffiliateLedgerQuery](docs/Model/AffiliateLedgerQuery.md)
 - [AffiliateLedgersResponse](docs/Model/AffiliateLedgersResponse.md)
 - [AffiliateLink](docs/Model/AffiliateLink.md)
 - [ApiUserApplicationProfile](docs/Model/ApiUserApplicationProfile.md)
 - [AutoOrder](docs/Model/AutoOrder.md)
 - [AutoOrderItem](docs/Model/AutoOrderItem.md)
 - [AutoOrderItemFutureSchedule](docs/Model/AutoOrderItemFutureSchedule.md)
 - [AutoOrderItemOption](docs/Model/AutoOrderItemOption.md)
 - [AutoOrderQuery](docs/Model/AutoOrderQuery.md)
 - [AutoOrderResponse](docs/Model/AutoOrderResponse.md)
 - [AutoOrdersResponse](docs/Model/AutoOrdersResponse.md)
 - [AvalaraConfig](docs/Model/AvalaraConfig.md)
 - [BaseResponse](docs/Model/BaseResponse.md)
 - [Cart](docs/Model/Cart.md)
 - [CartAffiliate](docs/Model/CartAffiliate.md)
 - [CartAffirmCheckoutResponse](docs/Model/CartAffirmCheckoutResponse.md)
 - [CartBilling](docs/Model/CartBilling.md)
 - [CartBuysafe](docs/Model/CartBuysafe.md)
 - [CartCheckout](docs/Model/CartCheckout.md)
 - [CartCoupon](docs/Model/CartCoupon.md)
 - [CartCurrencyConversion](docs/Model/CartCurrencyConversion.md)
 - [CartCustomerProfile](docs/Model/CartCustomerProfile.md)
 - [CartCustomerProfileAddress](docs/Model/CartCustomerProfileAddress.md)
 - [CartCustomerProfileCreditCard](docs/Model/CartCustomerProfileCreditCard.md)
 - [CartFinalizeOrderRequest](docs/Model/CartFinalizeOrderRequest.md)
 - [CartFinalizeOrderRequestOptions](docs/Model/CartFinalizeOrderRequestOptions.md)
 - [CartFinalizeOrderResponse](docs/Model/CartFinalizeOrderResponse.md)
 - [CartGift](docs/Model/CartGift.md)
 - [CartGiftCertificate](docs/Model/CartGiftCertificate.md)
 - [CartItem](docs/Model/CartItem.md)
 - [CartItemAttribute](docs/Model/CartItemAttribute.md)
 - [CartItemMultimedia](docs/Model/CartItemMultimedia.md)
 - [CartItemMultimediaThumbnail](docs/Model/CartItemMultimediaThumbnail.md)
 - [CartItemOption](docs/Model/CartItemOption.md)
 - [CartItemOptionValue](docs/Model/CartItemOptionValue.md)
 - [CartItemPhysical](docs/Model/CartItemPhysical.md)
 - [CartItemVariationSelection](docs/Model/CartItemVariationSelection.md)
 - [CartKitComponentOption](docs/Model/CartKitComponentOption.md)
 - [CartMarketing](docs/Model/CartMarketing.md)
 - [CartPayment](docs/Model/CartPayment.md)
 - [CartPaymentAffirm](docs/Model/CartPaymentAffirm.md)
 - [CartPaymentAmazon](docs/Model/CartPaymentAmazon.md)
 - [CartPaymentCheck](docs/Model/CartPaymentCheck.md)
 - [CartPaymentCreditCard](docs/Model/CartPaymentCreditCard.md)
 - [CartPaymentPurchaseOrder](docs/Model/CartPaymentPurchaseOrder.md)
 - [CartProfileLoginRequest](docs/Model/CartProfileLoginRequest.md)
 - [CartProfileLoginResponse](docs/Model/CartProfileLoginResponse.md)
 - [CartProfileRegisterRequest](docs/Model/CartProfileRegisterRequest.md)
 - [CartProfileRegisterResponse](docs/Model/CartProfileRegisterResponse.md)
 - [CartResponse](docs/Model/CartResponse.md)
 - [CartSettings](docs/Model/CartSettings.md)
 - [CartSettingsBilling](docs/Model/CartSettingsBilling.md)
 - [CartSettingsGift](docs/Model/CartSettingsGift.md)
 - [CartSettingsGiftWrap](docs/Model/CartSettingsGiftWrap.md)
 - [CartSettingsPayment](docs/Model/CartSettingsPayment.md)
 - [CartSettingsPaymentAmazon](docs/Model/CartSettingsPaymentAmazon.md)
 - [CartSettingsPaymentCreditCard](docs/Model/CartSettingsPaymentCreditCard.md)
 - [CartSettingsPaymentPayPal](docs/Model/CartSettingsPaymentPayPal.md)
 - [CartSettingsProvince](docs/Model/CartSettingsProvince.md)
 - [CartSettingsShipping](docs/Model/CartSettingsShipping.md)
 - [CartSettingsShippingCalendar](docs/Model/CartSettingsShippingCalendar.md)
 - [CartSettingsShippingEstimate](docs/Model/CartSettingsShippingEstimate.md)
 - [CartSettingsTaxes](docs/Model/CartSettingsTaxes.md)
 - [CartSettingsTerms](docs/Model/CartSettingsTerms.md)
 - [CartShipping](docs/Model/CartShipping.md)
 - [CartSummary](docs/Model/CartSummary.md)
 - [CartTaxes](docs/Model/CartTaxes.md)
 - [CartUpsellAfter](docs/Model/CartUpsellAfter.md)
 - [CartValidationRequest](docs/Model/CartValidationRequest.md)
 - [CartValidationResponse](docs/Model/CartValidationResponse.md)
 - [ChargebackDispute](docs/Model/ChargebackDispute.md)
 - [ChargebackDisputeResponse](docs/Model/ChargebackDisputeResponse.md)
 - [ChargebackDisputesResponse](docs/Model/ChargebackDisputesResponse.md)
 - [CheckoutAllowedCountriesResponse](docs/Model/CheckoutAllowedCountriesResponse.md)
 - [CheckoutHandoffRequest](docs/Model/CheckoutHandoffRequest.md)
 - [CheckoutHandoffResponse](docs/Model/CheckoutHandoffResponse.md)
 - [CheckoutSetupBrowserKeyRequest](docs/Model/CheckoutSetupBrowserKeyRequest.md)
 - [CheckoutSetupBrowserKeyResponse](docs/Model/CheckoutSetupBrowserKeyResponse.md)
 - [CheckoutStateProvinceResponse](docs/Model/CheckoutStateProvinceResponse.md)
 - [CityStateZip](docs/Model/CityStateZip.md)
 - [Country](docs/Model/Country.md)
 - [Coupon](docs/Model/Coupon.md)
 - [CouponAmountOffItems](docs/Model/CouponAmountOffItems.md)
 - [CouponAmountOffShipping](docs/Model/CouponAmountOffShipping.md)
 - [CouponAmountOffShippingWithItemsPurchase](docs/Model/CouponAmountOffShippingWithItemsPurchase.md)
 - [CouponAmountOffSubtotal](docs/Model/CouponAmountOffSubtotal.md)
 - [CouponAmountOffSubtotalAndShipping](docs/Model/CouponAmountOffSubtotalAndShipping.md)
 - [CouponAmountOffSubtotalFreeShippingWithPurchase](docs/Model/CouponAmountOffSubtotalFreeShippingWithPurchase.md)
 - [CouponAmountOffSubtotalWithBlockPurchase](docs/Model/CouponAmountOffSubtotalWithBlockPurchase.md)
 - [CouponAmountOffSubtotalWithItemsPurchase](docs/Model/CouponAmountOffSubtotalWithItemsPurchase.md)
 - [CouponAutomaticallyApplyCouponCodes](docs/Model/CouponAutomaticallyApplyCouponCodes.md)
 - [CouponCodesRequest](docs/Model/CouponCodesRequest.md)
 - [CouponCodesResponse](docs/Model/CouponCodesResponse.md)
 - [CouponDiscountItemWithItemPurchase](docs/Model/CouponDiscountItemWithItemPurchase.md)
 - [CouponDiscountItems](docs/Model/CouponDiscountItems.md)
 - [CouponEditorValues](docs/Model/CouponEditorValues.md)
 - [CouponFreeItemAndShippingWithSubtotal](docs/Model/CouponFreeItemAndShippingWithSubtotal.md)
 - [CouponFreeItemWithItemPurchase](docs/Model/CouponFreeItemWithItemPurchase.md)
 - [CouponFreeItemWithSubtotal](docs/Model/CouponFreeItemWithSubtotal.md)
 - [CouponFreeItemsWithItemPurchase](docs/Model/CouponFreeItemsWithItemPurchase.md)
 - [CouponFreeItemsWithMixMatchPurchase](docs/Model/CouponFreeItemsWithMixMatchPurchase.md)
 - [CouponFreeShipping](docs/Model/CouponFreeShipping.md)
 - [CouponFreeShippingSpecificItems](docs/Model/CouponFreeShippingSpecificItems.md)
 - [CouponFreeShippingWithItemsPurchase](docs/Model/CouponFreeShippingWithItemsPurchase.md)
 - [CouponFreeShippingWithSubtotal](docs/Model/CouponFreeShippingWithSubtotal.md)
 - [CouponMultipleAmountsOffItems](docs/Model/CouponMultipleAmountsOffItems.md)
 - [CouponNoDiscount](docs/Model/CouponNoDiscount.md)
 - [CouponPercentOffItemWithItemsQuantityPurchase](docs/Model/CouponPercentOffItemWithItemsQuantityPurchase.md)
 - [CouponPercentOffItems](docs/Model/CouponPercentOffItems.md)
 - [CouponPercentOffItemsAndFreeShipping](docs/Model/CouponPercentOffItemsAndFreeShipping.md)
 - [CouponPercentOffItemsWithItemsPurchase](docs/Model/CouponPercentOffItemsWithItemsPurchase.md)
 - [CouponPercentOffRetailPriceItems](docs/Model/CouponPercentOffRetailPriceItems.md)
 - [CouponPercentOffShipping](docs/Model/CouponPercentOffShipping.md)
 - [CouponPercentOffSubtotal](docs/Model/CouponPercentOffSubtotal.md)
 - [CouponPercentOffSubtotalAndFreeShipping](docs/Model/CouponPercentOffSubtotalAndFreeShipping.md)
 - [CouponPercentOffSubtotalLimit](docs/Model/CouponPercentOffSubtotalLimit.md)
 - [CouponPercentOffSubtotalWithItemsPurchase](docs/Model/CouponPercentOffSubtotalWithItemsPurchase.md)
 - [CouponPercentOffSubtotalWithSubtotal](docs/Model/CouponPercentOffSubtotalWithSubtotal.md)
 - [CouponQuery](docs/Model/CouponQuery.md)
 - [CouponResponse](docs/Model/CouponResponse.md)
 - [CouponTierAmount](docs/Model/CouponTierAmount.md)
 - [CouponTierItemDiscount](docs/Model/CouponTierItemDiscount.md)
 - [CouponTierPercent](docs/Model/CouponTierPercent.md)
 - [CouponTierQuantityAmount](docs/Model/CouponTierQuantityAmount.md)
 - [CouponTierQuantityPercent](docs/Model/CouponTierQuantityPercent.md)
 - [CouponTieredAmountOffItem](docs/Model/CouponTieredAmountOffItem.md)
 - [CouponTieredAmountOffSubtotal](docs/Model/CouponTieredAmountOffSubtotal.md)
 - [CouponTieredPercentOffItems](docs/Model/CouponTieredPercentOffItems.md)
 - [CouponTieredPercentOffShipping](docs/Model/CouponTieredPercentOffShipping.md)
 - [CouponTieredPercentOffSubtotal](docs/Model/CouponTieredPercentOffSubtotal.md)
 - [CouponsResponse](docs/Model/CouponsResponse.md)
 - [Currency](docs/Model/Currency.md)
 - [Customer](docs/Model/Customer.md)
 - [CustomerAffiliate](docs/Model/CustomerAffiliate.md)
 - [CustomerAttachment](docs/Model/CustomerAttachment.md)
 - [CustomerBilling](docs/Model/CustomerBilling.md)
 - [CustomerCard](docs/Model/CustomerCard.md)
 - [CustomerEditorValues](docs/Model/CustomerEditorValues.md)
 - [CustomerEmail](docs/Model/CustomerEmail.md)
 - [CustomerOrdersSummary](docs/Model/CustomerOrdersSummary.md)
 - [CustomerPricingTier](docs/Model/CustomerPricingTier.md)
 - [CustomerPrivacy](docs/Model/CustomerPrivacy.md)
 - [CustomerQuery](docs/Model/CustomerQuery.md)
 - [CustomerQuotesSummary](docs/Model/CustomerQuotesSummary.md)
 - [CustomerResponse](docs/Model/CustomerResponse.md)
 - [CustomerReviewer](docs/Model/CustomerReviewer.md)
 - [CustomerShipping](docs/Model/CustomerShipping.md)
 - [CustomerSoftwareEntitlement](docs/Model/CustomerSoftwareEntitlement.md)
 - [CustomerTaxCodes](docs/Model/CustomerTaxCodes.md)
 - [CustomersResponse](docs/Model/CustomersResponse.md)
 - [DataTablesServerSideResponse](docs/Model/DataTablesServerSideResponse.md)
 - [Distance](docs/Model/Distance.md)
 - [DistributionCenter](docs/Model/DistributionCenter.md)
 - [DistributionCentersResponse](docs/Model/DistributionCentersResponse.md)
 - [EmailBaseTemplateListResponse](docs/Model/EmailBaseTemplateListResponse.md)
 - [EmailCampaign](docs/Model/EmailCampaign.md)
 - [EmailCampaignResponse](docs/Model/EmailCampaignResponse.md)
 - [EmailCampaignsResponse](docs/Model/EmailCampaignsResponse.md)
 - [EmailCommseq](docs/Model/EmailCommseq.md)
 - [EmailCommseqEmail](docs/Model/EmailCommseqEmail.md)
 - [EmailCommseqEmailResponse](docs/Model/EmailCommseqEmailResponse.md)
 - [EmailCommseqEmailsResponse](docs/Model/EmailCommseqEmailsResponse.md)
 - [EmailCommseqResponse](docs/Model/EmailCommseqResponse.md)
 - [EmailCommseqStep](docs/Model/EmailCommseqStep.md)
 - [EmailCommseqsResponse](docs/Model/EmailCommseqsResponse.md)
 - [EmailCustomer](docs/Model/EmailCustomer.md)
 - [EmailFlow](docs/Model/EmailFlow.md)
 - [EmailFlowResponse](docs/Model/EmailFlowResponse.md)
 - [EmailFlowsResponse](docs/Model/EmailFlowsResponse.md)
 - [EmailList](docs/Model/EmailList.md)
 - [EmailListArchiveResponse](docs/Model/EmailListArchiveResponse.md)
 - [EmailListResponse](docs/Model/EmailListResponse.md)
 - [EmailListSegmentMembership](docs/Model/EmailListSegmentMembership.md)
 - [EmailListSubscribeResponse](docs/Model/EmailListSubscribeResponse.md)
 - [EmailListsResponse](docs/Model/EmailListsResponse.md)
 - [EmailSegment](docs/Model/EmailSegment.md)
 - [EmailSegmentArchiveResponse](docs/Model/EmailSegmentArchiveResponse.md)
 - [EmailSegmentResponse](docs/Model/EmailSegmentResponse.md)
 - [EmailSegmentsResponse](docs/Model/EmailSegmentsResponse.md)
 - [EmailStat](docs/Model/EmailStat.md)
 - [EmailStatSummaryResponse](docs/Model/EmailStatSummaryResponse.md)
 - [EmailTemplate](docs/Model/EmailTemplate.md)
 - [EmailTemplatesResponse](docs/Model/EmailTemplatesResponse.md)
 - [Error](docs/Model/Error.md)
 - [ErrorResponse](docs/Model/ErrorResponse.md)
 - [FulfillmentInventory](docs/Model/FulfillmentInventory.md)
 - [FulfillmentShipment](docs/Model/FulfillmentShipment.md)
 - [HTTPHeader](docs/Model/HTTPHeader.md)
 - [Item](docs/Model/Item.md)
 - [ItemAccounting](docs/Model/ItemAccounting.md)
 - [ItemAmember](docs/Model/ItemAmember.md)
 - [ItemAutoOrder](docs/Model/ItemAutoOrder.md)
 - [ItemAutoOrderStep](docs/Model/ItemAutoOrderStep.md)
 - [ItemAutoOrderStepArbitraryUnitCostSchedule](docs/Model/ItemAutoOrderStepArbitraryUnitCostSchedule.md)
 - [ItemAutoOrderStepGrandfatherPricing](docs/Model/ItemAutoOrderStepGrandfatherPricing.md)
 - [ItemCCBill](docs/Model/ItemCCBill.md)
 - [ItemChannelPartnerMapping](docs/Model/ItemChannelPartnerMapping.md)
 - [ItemChargeback](docs/Model/ItemChargeback.md)
 - [ItemChargebackAddendum](docs/Model/ItemChargebackAddendum.md)
 - [ItemChargebackAdjustmentRequest](docs/Model/ItemChargebackAdjustmentRequest.md)
 - [ItemCheckout](docs/Model/ItemCheckout.md)
 - [ItemContent](docs/Model/ItemContent.md)
 - [ItemContentAssignment](docs/Model/ItemContentAssignment.md)
 - [ItemContentAttribute](docs/Model/ItemContentAttribute.md)
 - [ItemContentMultimedia](docs/Model/ItemContentMultimedia.md)
 - [ItemContentMultimediaThumbnail](docs/Model/ItemContentMultimediaThumbnail.md)
 - [ItemDigitalDelivery](docs/Model/ItemDigitalDelivery.md)
 - [ItemDigitalItem](docs/Model/ItemDigitalItem.md)
 - [ItemEbay](docs/Model/ItemEbay.md)
 - [ItemEbayCategorySpecific](docs/Model/ItemEbayCategorySpecific.md)
 - [ItemEbayMarketListing](docs/Model/ItemEbayMarketListing.md)
 - [ItemEbayMarketPlaceAnalysis](docs/Model/ItemEbayMarketPlaceAnalysis.md)
 - [ItemEmailNotifications](docs/Model/ItemEmailNotifications.md)
 - [ItemEnrollment123](docs/Model/ItemEnrollment123.md)
 - [ItemGiftCertificate](docs/Model/ItemGiftCertificate.md)
 - [ItemGoogleProductSearch](docs/Model/ItemGoogleProductSearch.md)
 - [ItemIdentifiers](docs/Model/ItemIdentifiers.md)
 - [ItemInstantPaymentNotification](docs/Model/ItemInstantPaymentNotification.md)
 - [ItemInstantPaymentNotifications](docs/Model/ItemInstantPaymentNotifications.md)
 - [ItemInternal](docs/Model/ItemInternal.md)
 - [ItemKitComponent](docs/Model/ItemKitComponent.md)
 - [ItemKitDefinition](docs/Model/ItemKitDefinition.md)
 - [ItemOption](docs/Model/ItemOption.md)
 - [ItemOptionValue](docs/Model/ItemOptionValue.md)
 - [ItemOptionValueAdditionalItem](docs/Model/ItemOptionValueAdditionalItem.md)
 - [ItemOptionValueDigitalItem](docs/Model/ItemOptionValueDigitalItem.md)
 - [ItemPaymentProcessing](docs/Model/ItemPaymentProcessing.md)
 - [ItemPhysical](docs/Model/ItemPhysical.md)
 - [ItemPricing](docs/Model/ItemPricing.md)
 - [ItemPricingTier](docs/Model/ItemPricingTier.md)
 - [ItemPricingTierDiscount](docs/Model/ItemPricingTierDiscount.md)
 - [ItemPricingTierLimit](docs/Model/ItemPricingTierLimit.md)
 - [ItemRealtimePricing](docs/Model/ItemRealtimePricing.md)
 - [ItemRelated](docs/Model/ItemRelated.md)
 - [ItemRelatedItem](docs/Model/ItemRelatedItem.md)
 - [ItemReporting](docs/Model/ItemReporting.md)
 - [ItemResponse](docs/Model/ItemResponse.md)
 - [ItemRestriction](docs/Model/ItemRestriction.md)
 - [ItemRestrictionItem](docs/Model/ItemRestrictionItem.md)
 - [ItemRevguard](docs/Model/ItemRevguard.md)
 - [ItemReviews](docs/Model/ItemReviews.md)
 - [ItemSalesforce](docs/Model/ItemSalesforce.md)
 - [ItemShipping](docs/Model/ItemShipping.md)
 - [ItemShippingCase](docs/Model/ItemShippingCase.md)
 - [ItemShippingDestinationMarkup](docs/Model/ItemShippingDestinationMarkup.md)
 - [ItemShippingDestinationRestriction](docs/Model/ItemShippingDestinationRestriction.md)
 - [ItemShippingDistributionCenter](docs/Model/ItemShippingDistributionCenter.md)
 - [ItemShippingMethod](docs/Model/ItemShippingMethod.md)
 - [ItemShippingPackageRequirement](docs/Model/ItemShippingPackageRequirement.md)
 - [ItemTax](docs/Model/ItemTax.md)
 - [ItemTaxExemption](docs/Model/ItemTaxExemption.md)
 - [ItemThirdPartyEmailMarketing](docs/Model/ItemThirdPartyEmailMarketing.md)
 - [ItemVariantItem](docs/Model/ItemVariantItem.md)
 - [ItemVariation](docs/Model/ItemVariation.md)
 - [ItemVariationOption](docs/Model/ItemVariationOption.md)
 - [ItemWishlistMember](docs/Model/ItemWishlistMember.md)
 - [ItemsRequest](docs/Model/ItemsRequest.md)
 - [ItemsResponse](docs/Model/ItemsResponse.md)
 - [OauthRevokeSuccessResponse](docs/Model/OauthRevokeSuccessResponse.md)
 - [OauthTokenResponse](docs/Model/OauthTokenResponse.md)
 - [Order](docs/Model/Order.md)
 - [OrderAffiliate](docs/Model/OrderAffiliate.md)
 - [OrderAffiliateLedger](docs/Model/OrderAffiliateLedger.md)
 - [OrderAutoOrder](docs/Model/OrderAutoOrder.md)
 - [OrderBilling](docs/Model/OrderBilling.md)
 - [OrderBuysafe](docs/Model/OrderBuysafe.md)
 - [OrderChannelPartner](docs/Model/OrderChannelPartner.md)
 - [OrderCheckout](docs/Model/OrderCheckout.md)
 - [OrderCoupon](docs/Model/OrderCoupon.md)
 - [OrderDigitalItem](docs/Model/OrderDigitalItem.md)
 - [OrderDigitalOrder](docs/Model/OrderDigitalOrder.md)
 - [OrderEdi](docs/Model/OrderEdi.md)
 - [OrderFormat](docs/Model/OrderFormat.md)
 - [OrderFormatResponse](docs/Model/OrderFormatResponse.md)
 - [OrderFraudScore](docs/Model/OrderFraudScore.md)
 - [OrderGift](docs/Model/OrderGift.md)
 - [OrderGiftCertificate](docs/Model/OrderGiftCertificate.md)
 - [OrderInternal](docs/Model/OrderInternal.md)
 - [OrderItem](docs/Model/OrderItem.md)
 - [OrderItemEdi](docs/Model/OrderItemEdi.md)
 - [OrderItemEdiIdentification](docs/Model/OrderItemEdiIdentification.md)
 - [OrderItemEdiLot](docs/Model/OrderItemEdiLot.md)
 - [OrderItemOption](docs/Model/OrderItemOption.md)
 - [OrderItemOptionFileAttachment](docs/Model/OrderItemOptionFileAttachment.md)
 - [OrderItemProperty](docs/Model/OrderItemProperty.md)
 - [OrderLinkedShipment](docs/Model/OrderLinkedShipment.md)
 - [OrderMarketing](docs/Model/OrderMarketing.md)
 - [OrderPayment](docs/Model/OrderPayment.md)
 - [OrderPaymentCheck](docs/Model/OrderPaymentCheck.md)
 - [OrderPaymentCreditCard](docs/Model/OrderPaymentCreditCard.md)
 - [OrderPaymentECheck](docs/Model/OrderPaymentECheck.md)
 - [OrderPaymentPurchaseOrder](docs/Model/OrderPaymentPurchaseOrder.md)
 - [OrderPaymentTransaction](docs/Model/OrderPaymentTransaction.md)
 - [OrderPaymentTransactionDetail](docs/Model/OrderPaymentTransactionDetail.md)
 - [OrderProperty](docs/Model/OrderProperty.md)
 - [OrderQuery](docs/Model/OrderQuery.md)
 - [OrderQuote](docs/Model/OrderQuote.md)
 - [OrderReplacement](docs/Model/OrderReplacement.md)
 - [OrderReplacementItem](docs/Model/OrderReplacementItem.md)
 - [OrderReplacementResponse](docs/Model/OrderReplacementResponse.md)
 - [OrderResponse](docs/Model/OrderResponse.md)
 - [OrderSalesforce](docs/Model/OrderSalesforce.md)
 - [OrderShipping](docs/Model/OrderShipping.md)
 - [OrderSummary](docs/Model/OrderSummary.md)
 - [OrderTaxes](docs/Model/OrderTaxes.md)
 - [OrdersResponse](docs/Model/OrdersResponse.md)
 - [PricingTier](docs/Model/PricingTier.md)
 - [PricingTierNotification](docs/Model/PricingTierNotification.md)
 - [PricingTiersResponse](docs/Model/PricingTiersResponse.md)
 - [ResponseMetadata](docs/Model/ResponseMetadata.md)
 - [ResultSet](docs/Model/ResultSet.md)
 - [SelfConfig](docs/Model/SelfConfig.md)
 - [StateProvince](docs/Model/StateProvince.md)
 - [TaxCity](docs/Model/TaxCity.md)
 - [TaxCountry](docs/Model/TaxCountry.md)
 - [TaxCountryCode](docs/Model/TaxCountryCode.md)
 - [TaxCounty](docs/Model/TaxCounty.md)
 - [TaxJarConfig](docs/Model/TaxJarConfig.md)
 - [TaxPostalCode](docs/Model/TaxPostalCode.md)
 - [TaxProviderActivateResult](docs/Model/TaxProviderActivateResult.md)
 - [TaxProviderAvalara](docs/Model/TaxProviderAvalara.md)
 - [TaxProviderAvalaraCompaniesResult](docs/Model/TaxProviderAvalaraCompaniesResult.md)
 - [TaxProviderAvalaraCompany](docs/Model/TaxProviderAvalaraCompany.md)
 - [TaxProviderSelf](docs/Model/TaxProviderSelf.md)
 - [TaxProviderSelfCountriesResponse](docs/Model/TaxProviderSelfCountriesResponse.md)
 - [TaxProviderSelfRegionsResponse](docs/Model/TaxProviderSelfRegionsResponse.md)
 - [TaxProviderTaxJar](docs/Model/TaxProviderTaxJar.md)
 - [TaxProviderTestResult](docs/Model/TaxProviderTestResult.md)
 - [TaxProviderUltraCart](docs/Model/TaxProviderUltraCart.md)
 - [TaxProviderUltraCartState](docs/Model/TaxProviderUltraCartState.md)
 - [TaxProvidersResponse](docs/Model/TaxProvidersResponse.md)
 - [TaxState](docs/Model/TaxState.md)
 - [TaxStateCode](docs/Model/TaxStateCode.md)
 - [TempMultimedia](docs/Model/TempMultimedia.md)
 - [TempMultimediaResponse](docs/Model/TempMultimediaResponse.md)
 - [UltraCartConfig](docs/Model/UltraCartConfig.md)
 - [Webhook](docs/Model/Webhook.md)
 - [WebhookEventCategory](docs/Model/WebhookEventCategory.md)
 - [WebhookEventSubscription](docs/Model/WebhookEventSubscription.md)
 - [WebhookLog](docs/Model/WebhookLog.md)
 - [WebhookLogResponse](docs/Model/WebhookLogResponse.md)
 - [WebhookLogSummariesResponse](docs/Model/WebhookLogSummariesResponse.md)
 - [WebhookLogSummary](docs/Model/WebhookLogSummary.md)
 - [WebhookResponse](docs/Model/WebhookResponse.md)
 - [WebhookSampleRequest](docs/Model/WebhookSampleRequest.md)
 - [WebhookSampleRequestResponse](docs/Model/WebhookSampleRequestResponse.md)
 - [WebhooksResponse](docs/Model/WebhooksResponse.md)
 - [Weight](docs/Model/Weight.md)


## Documentation For Authorization


## ultraCartBrowserApiKey

- **Type**: API key
- **API key parameter name**: x-ultracart-browser-key
- **Location**: HTTP header

## ultraCartOauth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://secure.ultracart.com/rest/v2/oauth/authorize
- **Scopes**: 
 - **affiliate_read**: Allows you to read affiliate information.
 - **affiliate_write**: Allows you to write affiliate information.
 - **auto_order_read**: Allows you to read auto order information.
 - **auto_order_write**: Allows you to write auto order information.
 - **chargeback_read**: Allows you to read chargeback information.
 - **chargeback_write**: Allows you to write chargeback information.
 - **checkout_read**: Allows you to read checkout information.
 - **checkout_write**: Allows you to write checkout information.
 - **coupon_read**: Allows you to read coupon information.
 - **coupon_write**: Allows you to write coupon information.
 - **customer_read**: Allows you to read customer information.
 - **customer_write**: Allows you to write customer information.
 - **fulfillment_read**: Allows you to read fulfillment information.
 - **fulfillment_write**: Allows you to write fulfillment information.
 - **order_read**: Allows you to read order information.
 - **order_write**: Allows you to write order information.
 - **item_read**: Allows you to read item information.
 - **item_write**: Allows you to write item information.
 - **storefront_read**: Allows you to read storefront information.
 - **storefront_write**: Allows you to write storefront information.
 - **tax_read**: Allows you to read tax configuration information.
 - **tax_write**: Allows you to write tax configuration information.
 - **webhook_read**: Allows you to read webhook information.
 - **webhook_write**: Allows you to write webhook information.
 - **ultrabooks_read**: 1 of 2 required to use UltraBooks
 - **ultrabooks_write**: 2 of 2 required to use UltraBooks

## ultraCartSimpleApiKey

- **Type**: API key
- **API key parameter name**: x-ultracart-simple-key
- **Location**: HTTP header


## Author

support@ultracart.com


